==> doodle-image_sjs1_3-0.22.0-sources.jar: doodle/image/examples/ColorsAndShapes.scala <==
/*
 * Copyright 2015 Creative Scala
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package doodle
package image
package examples

import doodle.core._
import doodle.syntax.all._

object ColorsAndShapes {
  def size(n: Int): Double =
    50.0 + 12 * n

  def fading(n: Int): Color =
    Color.blue fadeOut (1 - n / 20.0).normalized

  def spinning(n: Int): Color =
    Color.blue desaturate 0.5.normalized spin (n * 30).degrees

  def circle(n: Int): Image =
    Image.circle(size(n))

  def square(n: Int): Image =
    Image.rectangle(2 * size(n), 2 * size(n))

  def triangle(n: Int): Image =
    Image.triangle(2 * size(n), 2 * size(n))

  def colored(shape: Int => Image, color: Int => Color): Int => Image =
    (n: Int) => shape(n) strokeWidth 10 strokeColor color(n)

  def concentricShapes(count: Int, singleShape: Int => Image): Image =
    count match {
      case 0 => Image.empty
      case n => singleShape(n) on concentricShapes(n - 1, singleShape)
    }

  val spacer = Image.square(10).noFill.noStroke

  def image =
    concentricShapes(10, colored(circle, spinning)) beside
      spacer beside
      concentricShapes(10, colored(triangle, fading)) beside
      spacer beside
      concentricShapes(10, colored(square, spinning))
}

==> doodle-image_sjs1_3-0.25.0-sources.jar: doodle/image/examples/ColorsAndShapes.scala <==
/*
 * Copyright 2015 Creative Scala
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package doodle
package image
package examples

import doodle.core.*
import doodle.syntax.all.*

object ColorsAndShapes {
  def size(n: Int): Double =
    50.0 + 12 * n

  def fading(n: Int): Color =
    Color.blue fadeOut (1 - n / 20.0).normalized

  def spinning(n: Int): Color =
    Color.blue desaturate 0.5.normalized spin (n * 30).degrees

  def circle(n: Int): Image =
    Image.circle(size(n))

  def square(n: Int): Image =
    Image.rectangle(2 * size(n), 2 * size(n))

  def triangle(n: Int): Image =
    Image.triangle(2 * size(n), 2 * size(n))

  def colored(shape: Int => Image, color: Int => Color): Int => Image =
    (n: Int) => shape(n) strokeWidth 10 strokeColor color(n)

  def concentricShapes(count: Int, singleShape: Int => Image): Image =
    count match {
      case 0 => Image.empty
      case n => singleShape(n) on concentricShapes(n - 1, singleShape)
    }

  val spacer = Image.square(10).noFill.noStroke

  def image =
    concentricShapes(10, colored(circle, spinning)) beside
      spacer beside
      concentricShapes(10, colored(triangle, fading)) beside
      spacer beside
      concentricShapes(10, colored(square, spinning))
}
